@@ -704,6 +704,8 @@ static Bool I830DrmModeInit(ScrnInfoPtr scrn)
 {
 	intel_screen_private *intel = intel_get_screen_private(scrn);
 
+	i830_init_bufmgr(scrn);
+
 	if (drmmode_pre_init(scrn, intel->drmSubFD, intel->cpp) == FALSE) {
 		xf86DrvMsg(scrn->scrnIndex, X_ERROR,
 			   "Kernel modesetting setup failed\n");
@@ -711,8 +713,6 @@ static Bool I830DrmModeInit(ScrnInfoPtr scrn)
 		return FALSE;
 	}
 
-	i830_init_bufmgr(scrn);
-
 	return TRUE;
 }
 
@@ -987,17 +987,17 @@ static Bool i830_try_memory_allocation(ScrnInfoPtr scrn)
 		   "Attempting memory allocation with %stiled buffers.\n",
 		   tiled ? "" : "un");
 
-	if (!i830_allocate_2d_memory(scrn))
-		goto failed;
+	intel->front_buffer = i830_allocate_framebuffer(scrn);
+	if (!intel->front_buffer) {
+		xf86DrvMsg(scrn->scrnIndex, X_INFO,
+			   "%siled allocation failed.\n",
+			   tiled ? "T" : "Unt");
+		return FALSE;
+	}
 
 	xf86DrvMsg(scrn->scrnIndex, X_INFO, "%siled allocation successful.\n",
 		   tiled ? "T" : "Unt");
 	return TRUE;
-
-failed:
-	xf86DrvMsg(scrn->scrnIndex, X_INFO, "%siled allocation failed.\n",
-		   tiled ? "T" : "Unt");
-	return FALSE;
 }
 
 /*
@@ -1016,13 +1016,6 @@ static Bool i830_memory_init(ScrnInfoPtr scrn)
 	Bool tiled = FALSE;
 
 	tiled = i830_tiled_width(intel, &scrn->displayWidth, intel->cpp);
-	/* Set up our video memory allocator for the chosen videoRam */
-	if (!i830_allocator_init(scrn, scrn->videoRam * KB(1))) {
-		xf86DrvMsg(scrn->scrnIndex, X_ERROR,
-			   "Couldn't initialize video memory allocator\n");
-		PreInitCleanup(scrn);
-		return FALSE;
-	}
 
 	xf86DrvMsg(scrn->scrnIndex,
 		   intel->pEnt->device->videoRam ? X_CONFIG : X_DEFAULT,
@@ -1189,6 +1182,11 @@ I830ScreenInit(int scrnIndex, ScreenPtr screen, int argc, char **argv)
 
 	i830_fixup_mtrrs(scrn);
 
+	intel_batch_init(scrn);
+
+	if (IS_I965G(intel))
+		gen4_render_state_init(scrn);
+
 	miClearVisualTypes();
 	if (!miSetVisualTypes(scrn->depth,
 			      miGetDefaultVisualMask(scrn->depth),
@@ -1202,12 +1200,6 @@ I830ScreenInit(int scrnIndex, ScreenPtr screen, int argc, char **argv)
 	if (scrn->virtualX > scrn->displayWidth)
 		scrn->displayWidth = scrn->virtualX;
 
-	/* If the front buffer is not a BO, we need to
-	 * set the initial framebuffer pixmap to point at
-	 * it
-	 */
-	scrn->fbOffset = intel->front_buffer->offset;
-
 	DPRINTF(PFX, "assert( if(!fbScreenInit(screen, ...) )\n");
 	if (!fbScreenInit(screen, NULL,
 			  scrn->virtualX, scrn->virtualY,
@@ -1373,13 +1365,6 @@ static void I830LeaveVT(int scrnIndex, int flags)
 
 	xf86_hide_cursors(scrn);
 
-	intel_sync(scrn);
-
-	intel_batch_teardown(scrn);
-
-	if (IS_I965G(intel))
-		gen4_render_state_cleanup(scrn);
-
 	ret = drmDropMaster(intel->drmSubFD);
 	if (ret)
 		xf86DrvMsg(scrn->scrnIndex, X_WARNING,
@@ -1399,33 +1384,16 @@ static Bool I830EnterVT(int scrnIndex, int flags)
 
 	ret = drmSetMaster(intel->drmSubFD);
 	if (ret) {
-		if (errno == EINVAL) {
-			xf86DrvMsg(scrn->scrnIndex, X_WARNING,
-				   "drmSetMaster failed: 2.6.29 or newer kernel required for "
-				   "multi-server DRI\n");
-		} else {
-			xf86DrvMsg(scrn->scrnIndex, X_WARNING,
-				   "drmSetMaster failed: %s\n",
-				   strerror(errno));
-		}
+		xf86DrvMsg(scrn->scrnIndex, X_WARNING,
+			   "drmSetMaster failed: %s\n",
+			   strerror(errno));
 	}
 
-	if (!i830_bind_all_memory(scrn))
-		return FALSE;
-
-	i830_describe_allocations(scrn, 1, "");
-
-	intel_batch_init(scrn);
-
-	if (IS_I965G(intel))
-		gen4_render_state_init(scrn);
+	i830_set_gem_max_sizes(scrn);
 
 	if (!xf86SetDesiredModes(scrn))
 		return FALSE;
 
-	/* Mark all state as being clobbered. */
-	intel->last_3d = LAST_3D_OTHER;
-
 	return TRUE;
 }
 
@@ -1453,13 +1421,19 @@ static Bool I830CloseScreen(int scrnIndex, ScreenPtr screen)
 	if (intel->front_buffer) {
 		i830_set_pixmap_bo(screen->GetScreenPixmap(screen), NULL);
 		drmmode_closefb(scrn);
-		i830_free_memory(scrn, intel->front_buffer);
+		drm_intel_bo_unreference(intel->front_buffer);
 		intel->front_buffer = NULL;
 	}
 
+	intel_batch_teardown(scrn);
+
+	if (IS_I965G(intel))
+		gen4_render_state_cleanup(scrn);
+
 	xf86_cursors_fini(screen);
 
-	i830_allocator_fini(scrn);
+	/* Free most of the allocations */
+	i830_reset_allocations(scrn);
 
 	i965_free_video(scrn);
 
